#! /usr/local/bin/python3

#############
## STARTER ##
#############
class Home:
    def __init__(self, line):
        '''
        This is the constructor method, which takes one parameter (a line), and
        splits it up into discrete attributes (its address, price, bedrooms,
        bathrooms, school_ranking, and in_foreclosure).
        '''
        cells = line.split(',')
        #print(cells)
        self.address = cells[0]
        self.price = int(cells[1])
        self.bedrooms = int(cells[2])
        self.bathrooms = int(cells[3])
        self.school_ranking = int(cells[4])
        if cells[5].strip() == '1': 
            self.in_foreclosure = True
        else:
            self.in_foreclosure = False
        
    def __str__(self):
        # String formatting reference:  http://docs.python.org/3.1/library/string.html
        return '{:30} ${:<10,} {:<5} {:<5} {:<25} {:<5}'.format(
            self.address,
            self.price,
            self.bedrooms,
            self.bathrooms,
            self.get_ranking_text(),
            'Yes' if self.in_foreclosure else 'No'  
        )
        
    def show_home_price(self):
        print('${}'.format(self.price))
        
    def get_ranking_text(self):
        txt = '({}) '.format(self.school_ranking)
        if self.school_ranking <= 4:
            txt += 'Low Performing'
        elif self.school_ranking <= 7:
            txt += 'Medium Performing'
        else:
            txt += 'High Performing'
        return txt
        
    def __repr__(self):
        return '<' + self.__str__() + '>'
