#! /usr/local/bin/python3
from home import Home

class DataApi:
    def __init__(self):
        self.homes = []
        
    def read_file(self, file_name):
        '''
        Reads a file and populates self.homes with a list of Home objects
        '''
        f = open(file_name)
        for line in f.readlines()[1:]:
            self.homes.append(Home(line))
            
    def print_selection(self, homes):
        '''
        Prints out a nicely formatted list of homes
        '''
        header_string = '{:30} {:10} {:5} {:5} {:25} {:<5}'.format(
            'Address', 'Price', 'Beds', 'Bath', 'School Rank', 'In FC?')
        print('-'*len(header_string))
        print(header_string)
        print('-'*len(header_string))
        
        for home in homes:
            print(home) 
                
    def get_homes_on_or_above_school_ranking(self, school_ranking):
        '''
        Returns only those homes with a school ranking greater than or equal
        to the school_ranking parameter
        '''
        homes = []
        for home in self.homes:
            if home.school_ranking >= school_ranking:
                homes.append(home)
        return homes
    
    def get_number_of_homes_in_foreclosure(self):
        num_forclosures = 0
        for home in self.homes:
            if home.in_foreclosure:
                num_forclosures += 1
        return num_forclosures
    
    def get_avg_num_of_bathrooms(self):
        '''
        QUESTION 2
        Implement this method, which should calculate the average number of
        bathrooms (returns a floating point number) in the homes.csv file
        '''
        return 0.0 #replace with variable containing the correct number
        
        
    def get_homes_that_match_any_param(self, bedrooms=None, bathrooms=None,
                                       max_price=None, in_foreclosure=None):
        '''
        QUESTION 3
        Implement this method, which should return an array of Home objects
        that match ANY of the arguments passed in by the user.
        '''
        return [] #empty list
    
    def get_homes_that_match_all_params(self, bedrooms, bathrooms,
                                            max_price, in_foreclosure):
        '''
        Implement this method, which should return an array of Home objects
        that match ALL of the arguments passed in by the user.
        '''
        return [] #empty list
             

#############
## STARTER ##
#############   
if __name__ == '__main__':
    api = DataApi()
    api.read_file('homes.csv')
    
    input('\nPress any key to show all homes...')
    api.print_selection(api.homes)
    
    input('\nPress any key to show homes with a school score of at least 7...')
    homes_in_decent_school_district = api.get_homes_on_or_above_school_ranking(7)
    api.print_selection(homes_in_decent_school_district)
    
    input('\nPress any key to see how many homes are in foreclosure...')
    print('\nIn foreclosure: {}'.format(api.get_number_of_homes_in_foreclosure()))
    
    
    #########################################################################
    ## UN-COMMENT THIS SECTION WHEN YOU HAVE IMPLEMENTED THE CORRESPONDING ##
    ## METHODS IN THE DataApi CLASS                                        ##
    #########################################################################
    '''
    # implement get_avg_num_of_bathrooms method above:
    print('\nAverage number of bathrooms: {}'.format(api.get_avg_num_of_bathrooms()))
    
    # Code to collect user input:   
    print('\nEnter your house search preferences:')
    print('------------------------------------')
    num_bed = int(input('Number of bedrooms? '))
    num_bath = int(input('Number of bathrooms? '))
    price = int(input('What\'s your price? '))
    in_fc = bool(int(input('Type 0 for No foreclosure, 1 for foreclosure: ')))
    
    # Verify that your have saved the user's input correctly:
    print('\n\nYour criteria:')
    print('Bedrooms: {}'.format(num_bed))
    print('Bathrooms: {}'.format(num_bath))
    print('Price: {}'.format(price))
    print('In foreclosure: {}'.format(in_fc))
    
    # Query for homes that match ANY of the criteria...
    homes_any = api.get_homes_that_match_any_param(num_bed, num_bath, price, in_fc)
    print('\nHomes that match ANY of the criteria...')
    api.print_selection(homes_any)
    
    # Query for homes that match ALL of the criteria...
    homes_all = api.get_homes_that_match_all_params(num_bed, num_bath, price, in_fc)
    print('\nHomes that match ALL of the criteria...')
    api.print_selection(homes_all)
    '''
    
    
    
    
    
    
    
